# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: nexum.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'nexum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bnexum.proto\x12\x05nexum\"H\n\nWorkflowIR\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\t\x12\x14\n\x0cversion_hash\x18\x02 \x01(\t\x12\x0f\n\x07ir_json\x18\x03 \x01(\t\"A\n\x0b\x41\x63kResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x15\n\rcompatibility\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"M\n\x0cStartRequest\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\t\x12\x14\n\x0cversion_hash\x18\x02 \x01(\t\x12\x12\n\ninput_json\x18\x03 \x01(\t\"%\n\rStartResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"6\n\x0bPollRequest\x12\x11\n\tworker_id\x18\x01 \x01(\t\x12\x14\n\x0cversion_hash\x18\x02 \x01(\t\"\xb8\x02\n\x0cPollResponse\x12\x10\n\x08has_task\x18\x01 \x01(\x08\x12\x0f\n\x07task_id\x18\x02 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x03 \x01(\t\x12\x0f\n\x07node_id\x18\x04 \x01(\t\x12\x12\n\ninput_json\x18\x05 \x01(\t\x12\x17\n\x0fidempotency_key\x18\x06 \x01(\t\x12\x11\n\tnode_type\x18\x07 \x01(\t\x12\x15\n\rmap_item_json\x18\n \x01(\t\x12\x16\n\x0eis_map_subtask\x18\x0b \x01(\x08\x12\x11\n\tmap_index\x18\x0c \x01(\x05\x12\x11\n\tmap_total\x18\r \x01(\x05\x12\x18\n\x10sub_execution_id\x18\x0e \x01(\t\x12\x17\n\x0fsub_workflow_id\x18\x0f \x01(\t\x12\x16\n\x0esub_input_json\x18\x10 \x01(\t\"7\n\x0f\x43ompleteRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x13\n\x0boutput_json\x18\x02 \x01(\t\"5\n\x0b\x46\x61ilRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x15\n\rerror_message\x18\x02 \x01(\t\"%\n\rStatusRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\">\n\x0eStatusResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x1c\n\x14\x63ompleted_nodes_json\x18\x02 \x01(\t\"A\n\x0bListRequest\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\"w\n\x10\x45xecutionSummary\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x02 \x01(\t\x12\x14\n\x0cversion_hash\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x12\n\ncreated_at\x18\x05 \x01(\t\";\n\x0cListResponse\x12+\n\nexecutions\x18\x01 \x03(\x0b\x32\x17.nexum.ExecutionSummary\"%\n\rCancelRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"*\n\x13ListVersionsRequest\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\t\"\x81\x01\n\x0bVersionInfo\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\t\x12\x14\n\x0cversion_hash\x18\x02 \x01(\t\x12\x15\n\rcompatibility\x18\x03 \x01(\t\x12\x15\n\rregistered_at\x18\x04 \x01(\t\x12\x19\n\x11\x61\x63tive_executions\x18\x05 \x01(\x05\"<\n\x14ListVersionsResponse\x12$\n\x08versions\x18\x01 \x03(\x0b\x32\x12.nexum.VersionInfo\"Z\n\x0e\x41pproveRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\t\x12\x10\n\x08\x61pprover\x18\x03 \x01(\t\x12\x0f\n\x07\x63omment\x18\x04 \x01(\t\"X\n\rRejectRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\t\x12\x10\n\x08\x61pprover\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\"\x0e\n\x0c\x45mptyRequest\"e\n\x13PendingApprovalItem\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\t\x12\x13\n\x0bworkflow_id\x18\x03 \x01(\t\x12\x12\n\nstarted_at\x18\x04 \x01(\t\"E\n\x18PendingApprovalsResponse\x12)\n\x05items\x18\x01 \x03(\x0b\x32\x1a.nexum.PendingApprovalItem2\xed\x05\n\x0cNexumService\x12\x39\n\x10RegisterWorkflow\x12\x11.nexum.WorkflowIR\x1a\x12.nexum.AckResponse\x12;\n\x0eStartExecution\x12\x13.nexum.StartRequest\x1a\x14.nexum.StartResponse\x12\x33\n\x08PollTask\x12\x12.nexum.PollRequest\x1a\x13.nexum.PollResponse\x12:\n\x0c\x43ompleteTask\x12\x16.nexum.CompleteRequest\x1a\x12.nexum.AckResponse\x12\x32\n\x08\x46\x61ilTask\x12\x12.nexum.FailRequest\x1a\x12.nexum.AckResponse\x12\x38\n\tGetStatus\x12\x14.nexum.StatusRequest\x1a\x15.nexum.StatusResponse\x12\x39\n\x0eListExecutions\x12\x12.nexum.ListRequest\x1a\x13.nexum.ListResponse\x12;\n\x0f\x43\x61ncelExecution\x12\x14.nexum.CancelRequest\x1a\x12.nexum.AckResponse\x12O\n\x14ListWorkflowVersions\x12\x1a.nexum.ListVersionsRequest\x1a\x1b.nexum.ListVersionsResponse\x12\x38\n\x0b\x41pproveTask\x12\x15.nexum.ApproveRequest\x1a\x12.nexum.AckResponse\x12\x36\n\nRejectTask\x12\x14.nexum.RejectRequest\x1a\x12.nexum.AckResponse\x12K\n\x13GetPendingApprovals\x12\x13.nexum.EmptyRequest\x1a\x1f.nexum.PendingApprovalsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nexum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_WORKFLOWIR']._serialized_start=22
  _globals['_WORKFLOWIR']._serialized_end=94
  _globals['_ACKRESPONSE']._serialized_start=96
  _globals['_ACKRESPONSE']._serialized_end=161
  _globals['_STARTREQUEST']._serialized_start=163
  _globals['_STARTREQUEST']._serialized_end=240
  _globals['_STARTRESPONSE']._serialized_start=242
  _globals['_STARTRESPONSE']._serialized_end=279
  _globals['_POLLREQUEST']._serialized_start=281
  _globals['_POLLREQUEST']._serialized_end=335
  _globals['_POLLRESPONSE']._serialized_start=338
  _globals['_POLLRESPONSE']._serialized_end=650
  _globals['_COMPLETEREQUEST']._serialized_start=652
  _globals['_COMPLETEREQUEST']._serialized_end=707
  _globals['_FAILREQUEST']._serialized_start=709
  _globals['_FAILREQUEST']._serialized_end=762
  _globals['_STATUSREQUEST']._serialized_start=764
  _globals['_STATUSREQUEST']._serialized_end=801
  _globals['_STATUSRESPONSE']._serialized_start=803
  _globals['_STATUSRESPONSE']._serialized_end=865
  _globals['_LISTREQUEST']._serialized_start=867
  _globals['_LISTREQUEST']._serialized_end=932
  _globals['_EXECUTIONSUMMARY']._serialized_start=934
  _globals['_EXECUTIONSUMMARY']._serialized_end=1053
  _globals['_LISTRESPONSE']._serialized_start=1055
  _globals['_LISTRESPONSE']._serialized_end=1114
  _globals['_CANCELREQUEST']._serialized_start=1116
  _globals['_CANCELREQUEST']._serialized_end=1153
  _globals['_LISTVERSIONSREQUEST']._serialized_start=1155
  _globals['_LISTVERSIONSREQUEST']._serialized_end=1197
  _globals['_VERSIONINFO']._serialized_start=1200
  _globals['_VERSIONINFO']._serialized_end=1329
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=1331
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=1391
  _globals['_APPROVEREQUEST']._serialized_start=1393
  _globals['_APPROVEREQUEST']._serialized_end=1483
  _globals['_REJECTREQUEST']._serialized_start=1485
  _globals['_REJECTREQUEST']._serialized_end=1573
  _globals['_EMPTYREQUEST']._serialized_start=1575
  _globals['_EMPTYREQUEST']._serialized_end=1589
  _globals['_PENDINGAPPROVALITEM']._serialized_start=1591
  _globals['_PENDINGAPPROVALITEM']._serialized_end=1692
  _globals['_PENDINGAPPROVALSRESPONSE']._serialized_start=1694
  _globals['_PENDINGAPPROVALSRESPONSE']._serialized_end=1763
  _globals['_NEXUMSERVICE']._serialized_start=1766
  _globals['_NEXUMSERVICE']._serialized_end=2515
# @@protoc_insertion_point(module_scope)
